# Hackerrank-Solution-Crawler
Crawls solutions of hackerrank and stores as local files.

## How to use it
- Pip install the package `pip install hsc`
- Run the command `python hsc`
- Login with your Hackerrank Credentials
- Enter the limit of successful solutions you want to be crawled
- A new folder with name **Hackerrank** would be created with all your solutions in it
